@@ -25,7 +25,7 @@ ExportAddressbookJobInterfaceImpl::ExportAddressbookJobInterfaceImpl(QObject *pa
 
 ExportAddressbookJobInterfaceImpl::~ExportAddressbookJobInterfaceImpl() = default;
 
-QVector<Utils::AkonadiInstanceInfo> ExportAddressbookJobInterfaceImpl::listOfResource()
+QList<Utils::AkonadiInstanceInfo> ExportAddressbookJobInterfaceImpl::listOfResource()
 {
     return Utils::listOfResource();
 }
@@ -90,3 +90,5 @@ ExportAddressbookJobInterfaceImpl::createResource(const QString &resources, cons
     Q_UNREACHABLE();
     return {};
 }
+
+#include "moc_exportaddressbookjobinterfaceimpl.cpp"
