@@ -33,7 +33,7 @@ void ExportAddressbookJobInterfaceTest::exportAddressBook()
     QFETCH(Utils::StoredTypes, options);
     std::unique_ptr<TestExportFile> file{new TestExportFile(this)};
     file->setPathConfig(configpath);
-    QVector<Utils::AkonadiInstanceInfo> lstInfo;
+    QList<Utils::AkonadiInstanceInfo> lstInfo;
     Utils::AkonadiInstanceInfo info;
 
     info.identifier = QStringLiteral("akonadi_vcarddir_resource_1");
@@ -53,3 +53,5 @@ void ExportAddressbookJobInterfaceTest::exportAddressBook()
     file->start();
     delete exportNote;
 }
+
+#include "moc_exportaddressbookjobinterfacetest.cpp"
