@@ -16,8 +16,8 @@ public:
     explicit LogCreatingResource(QObject *parent = nullptr);
     ~LogCreatingResource() override;
     void appendText(const QString &str);
-    Q_REQUIRED_RESULT QString logPath() const;
-    Q_REQUIRED_RESULT QString logCreateResource(const QString &resources, const QString &name, const QMap<QString, QVariant> &settings, bool synchronizeTree);
+    [[nodiscard]] QString logPath() const;
+    [[nodiscard]] QString logCreateResource(const QString &resources, const QString &name, const QMap<QString, QVariant> &settings, bool synchronizeTree);
     void logSynchronizeResource(const QStringList &lst);
     void logRegisterSpecialCollection(Akonadi::SpecialMailCollections::Type type, qint64 colId);
 
