@@ -9,8 +9,8 @@
 #include "resourceconverterimpl.h"
 #include "smtpmailtransport.h"
 #include <Akonadi/CollectionFetchJob>
-#include <KIdentityManagement/Identity>
-#include <KIdentityManagement/IdentityManager>
+#include <KIdentityManagementCore/Identity>
+#include <KIdentityManagementCore/IdentityManager>
 #include <MailCommon/FilterImporterExporter>
 #include <MailCommon/FilterManager>
 #include <PimCommonAkonadi/CreateResource>
@@ -18,7 +18,7 @@ using namespace Akonadi;
 
 ImportMailJobInterfaceImpl::ImportMailJobInterfaceImpl(QObject *parent, Utils::StoredTypes typeSelected, ArchiveStorage *archiveStorage, int numberOfStep)
     : ImportMailJobInterface(parent, typeSelected, archiveStorage, numberOfStep)
-    , mIdentityManager(KIdentityManagement::IdentityManager::self())
+    , mIdentityManager(KIdentityManagementCore::IdentityManager::self())
 {
 }
 
@@ -83,7 +83,7 @@ void ImportMailJobInterfaceImpl::importFilters(const QString &filename)
 {
     bool canceled = false;
     MailCommon::FilterImporterExporter exportFilters;
-    const QVector<MailCommon::MailFilter *> lstFilter = exportFilters.importFilters(canceled, MailCommon::FilterImporterExporter::KMailFilter, filename);
+    const QList<MailCommon::MailFilter *> lstFilter = exportFilters.importFilters(canceled, MailCommon::FilterImporterExporter::KMailFilter, filename);
     if (!canceled) {
         MailCommon::FilterManager::instance()->appendFilters(lstFilter);
     }
@@ -104,7 +104,7 @@ QString ImportMailJobInterfaceImpl::adaptNewResourceUrl(bool overwriteResources,
 void ImportMailJobInterfaceImpl::addNewIdentity(const QString &name, KConfigGroup &group, int defaultIdentity, int oldUid)
 {
     const QString uniqueName = uniqueIdentityName(name);
-    KIdentityManagement::Identity *identity = &mIdentityManager->newFromScratch(uniqueName);
+    KIdentityManagementCore::Identity *identity = &mIdentityManager->newFromScratch(uniqueName);
     group.writeEntry(QStringLiteral("Identity"), uniqueName);
     group.sync();
 
@@ -193,3 +193,5 @@ void ImportMailJobInterfaceImpl::addMailTransport(MailTransport::Transport *mt,
     mHashTransport.insert(transportId, mt->id());
     // qDebug() << " void ImportMailJobInterface::addMailTransport(MailTransport::Transport *mt, int defaultTransport, int transportId)" << transportId;
 }
+
+#include "moc_importmailjobinterfaceimpl.cpp"
