@@ -44,8 +44,8 @@
 #include <dialog/pimdataexporterconfiguredialog.h>
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
-#include <KUserFeedbackQt6/NotificationPopup>
-#include <KUserFeedbackQt6/Provider>
+#include <KUserFeedback/NotificationPopup>
+#include <KUserFeedback/Provider>
 #endif
 
 PimDataExporterWindow::PimDataExporterWindow(QWidget *parent)
